A Plackett–Luce likelihood only identifies relative strengths. This prior
is defined on the positive, unnormalised strengths used by the sampler;
pl_identifiability() controls the scale used when strengths are reported.
A Plackett–Luce likelihood only identifies relative strengths. This prior
is defined on the positive, unnormalised strengths used by the sampler;
pl_identifiability() controls the scale used when strengths are reported.