This is a compact numerical companion to plot_strength_summary(). The reported strengths are relative: for Plackett–Luce fits, the default reporting scale has geometric mean one; for Bradley–Terry fits, a larger value means a higher chance of beating an item with a smaller value.